==> apimgmt-app-1.1.0-sources.jar: com/digiwin/athena/apimgmt/services/ApiMgmtDaoService.java <==
package com.digiwin.athena.apimgmt.services;

import com.digiwin.athena.apimgmt.dao.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service("com.digiwin.dsms.service.DsmsDaoService")
public class ApiMgmtDaoService {

	@Autowired
	private ApiMgmtStandardApiDataNameDao standardApiDataNameDao;

	@Autowired
	private ApiMgmtStandardApiVersionDao standardApiVersionDao;

	@Autowired
	private ApiMgmtStandardDataNameDao standardDataNameDao;

	@Autowired
	private ApiMgmtStandardApiGroupDao standardApiGroupDao;
	
	@Autowired
	private ApiMgmtStandardApiPagingDao standardApiPagingDao;

	@Autowired
	private ApiMgmtApprovedStatusDao approvedStatusDao;
	
	@Autowired
	private ApiMgmtPrdApiVersionMappingDao prdApiVersionMappingDao;
	
	@Autowired
	private ApimgmtProductDao productDao;
	
	@Autowired
	private ApiMgmtStateCodeDao stateCodeDao;


	// 2017-04-12 Neville Hsieh
	public ApiMgmtStandardApiDataNameDao getStandardApiDataNameDao() {
		return standardApiDataNameDao;
	}

	// 2017-04-12 Neville Hsieh
	public void setStandardApiDataNameDao(ApiMgmtStandardApiDataNameDao standardApiDataNameDao) {
		this.standardApiDataNameDao = standardApiDataNameDao;
	}

	// 2018-01-22 Cherry Wang
	public ApiMgmtStandardDataNameDao getStandardDataNameDao() {
		return standardDataNameDao;
	}

	// 2018-01-22 Cherry Wang
	public void setStandardDataNameDao(ApiMgmtStandardDataNameDao standardDataNameDao) {
		this.standardDataNameDao = standardDataNameDao;
	}

	// 2018-08-08 Cherry Wang
	public ApiMgmtStandardApiGroupDao getStandardApiGroupDao() {
		return standardApiGroupDao;
	}

	// 2018-08-08 Cherry Wang
	public void setStandardApiGroupDao(ApiMgmtStandardApiGroupDao pStandardApiGroupDao) {
		this.standardApiGroupDao = pStandardApiGroupDao;
	}
	
	public ApiMgmtStandardApiPagingDao getStandardApiPagingDao() {
		return standardApiPagingDao;
	}

	public void setStandardApiPagingDao(ApiMgmtStandardApiPagingDao pStandardApiPagingDao) {
		this.standardApiPagingDao = pStandardApiPagingDao;
	}

	// 2018-08-08 Cherry Wang
	public ApiMgmtApprovedStatusDao getApprovedStatusDao() {
		return approvedStatusDao;
	}

	// 2018-08-08 Cherry Wang
	public void setApprovedStatusDao(ApiMgmtApprovedStatusDao pApprovedStatusDao) {
		this.approvedStatusDao = pApprovedStatusDao;
	}

	public ApiMgmtStandardApiVersionDao getStandardApiVersionDao() {
		return standardApiVersionDao;
	}

	public void setStandardApiVersionDao(ApiMgmtStandardApiVersionDao standardApiVersionDao) {
		this.standardApiVersionDao = standardApiVersionDao;
	}
	
	public ApiMgmtPrdApiVersionMappingDao getPrdApiVersionMappingDao() {
		return prdApiVersionMappingDao;
	}
	
	public ApimgmtProductDao getProductDao() {
		return productDao;
	}
	
	public void setProductDao(ApimgmtProductDao productDao) {
		this.productDao = productDao;
	}

	public ApiMgmtStateCodeDao getStateCodeDao() {
		return stateCodeDao;
	}

	public void setStateCodeDao(ApiMgmtStateCodeDao stateCodeDao) {
		this.stateCodeDao = stateCodeDao;
	}

}

==> apimgmt-app-1.1.0-20251024.114014-2-sources.jar: com/digiwin/athena/apimgmt/services/ApiMgmtDaoService.java <==
package com.digiwin.athena.apimgmt.services;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.digiwin.athena.apimgmt.dao.ApiMgmtApprovedStatusDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtPrdApiVersionMappingDao;
import com.digiwin.athena.apimgmt.dao.ApimgmtProductDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardApiDataNameDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardApiGroupDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardApiPagingDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardApiVersionDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStandardDataNameDao;
import com.digiwin.athena.apimgmt.dao.ApiMgmtStateCodeDao;

@Service("com.digiwin.dsms.service.DsmsDaoService")
public class ApiMgmtDaoService {

	@Autowired
	private ApiMgmtStandardApiDataNameDao standardApiDataNameDao;

	@Autowired
	private ApiMgmtStandardApiVersionDao standardApiVersionDao;

	@Autowired
	private ApiMgmtStandardDataNameDao standardDataNameDao;

	@Autowired
	private ApiMgmtStandardApiGroupDao standardApiGroupDao;
	
	@Autowired
	private ApiMgmtStandardApiPagingDao standardApiPagingDao;

	@Autowired
	private ApiMgmtApprovedStatusDao approvedStatusDao;
	
	@Autowired
	private ApiMgmtPrdApiVersionMappingDao prdApiVersionMappingDao;
	
	@Autowired
	private ApimgmtProductDao productDao;
	
	@Autowired
	private ApiMgmtStateCodeDao stateCodeDao;


	// 2017-04-12 Neville Hsieh
	public ApiMgmtStandardApiDataNameDao getStandardApiDataNameDao() {
		return standardApiDataNameDao;
	}

	// 2017-04-12 Neville Hsieh
	public void setStandardApiDataNameDao(ApiMgmtStandardApiDataNameDao standardApiDataNameDao) {
		this.standardApiDataNameDao = standardApiDataNameDao;
	}

	// 2018-01-22 Cherry Wang
	public ApiMgmtStandardDataNameDao getStandardDataNameDao() {
		return standardDataNameDao;
	}

	// 2018-01-22 Cherry Wang
	public void setStandardDataNameDao(ApiMgmtStandardDataNameDao standardDataNameDao) {
		this.standardDataNameDao = standardDataNameDao;
	}

	// 2018-08-08 Cherry Wang
	public ApiMgmtStandardApiGroupDao getStandardApiGroupDao() {
		return standardApiGroupDao;
	}

	// 2018-08-08 Cherry Wang
	public void setStandardApiGroupDao(ApiMgmtStandardApiGroupDao pStandardApiGroupDao) {
		this.standardApiGroupDao = pStandardApiGroupDao;
	}
	
	public ApiMgmtStandardApiPagingDao getStandardApiPagingDao() {
		return standardApiPagingDao;
	}

	public void setStandardApiPagingDao(ApiMgmtStandardApiPagingDao pStandardApiPagingDao) {
		this.standardApiPagingDao = pStandardApiPagingDao;
	}

	// 2018-08-08 Cherry Wang
	public ApiMgmtApprovedStatusDao getApprovedStatusDao() {
		return approvedStatusDao;
	}

	// 2018-08-08 Cherry Wang
	public void setApprovedStatusDao(ApiMgmtApprovedStatusDao pApprovedStatusDao) {
		this.approvedStatusDao = pApprovedStatusDao;
	}

	public ApiMgmtStandardApiVersionDao getStandardApiVersionDao() {
		return standardApiVersionDao;
	}

	public void setStandardApiVersionDao(ApiMgmtStandardApiVersionDao standardApiVersionDao) {
		this.standardApiVersionDao = standardApiVersionDao;
	}
	
	public ApiMgmtPrdApiVersionMappingDao getPrdApiVersionMappingDao() {
		return prdApiVersionMappingDao;
	}
	
	public ApimgmtProductDao getProductDao() {
		return productDao;
	}
	
	public void setProductDao(ApimgmtProductDao productDao) {
		this.productDao = productDao;
	}

	public ApiMgmtStateCodeDao getStateCodeDao() {
		return stateCodeDao;
	}

	public void setStateCodeDao(ApiMgmtStateCodeDao stateCodeDao) {
		this.stateCodeDao = stateCodeDao;
	}

}
